@@ -246,7 +246,9 @@ void dtd_quitSymbols()
   {
     assert0(CfgSyms != (symbol*)NULL,"dtdSymbols not initialized");
     if( CfgSyms != (symbol*)NULL ) FreeMem(CfgSyms);
+    CfgSyms = (symbol*)NULL;
     if( PrdSyms != (symbol*)NULL ) FreeMem(PrdSyms);
+    PrdSyms = (symbol*)NULL;
   }
 }
 
