@@ -210,9 +210,13 @@ PT_Term PT_consT(PT_Term left, PT_Term right)
 /* C: child node concatenation:
       child list = cons('left','right') 
 */
-{
+{ PTERM* t = NULL;
   BUG_NULL(left); PT_BUG_TYP(left,True);
+  /* breaks strict-aliasing rules
   *PT_T_NXT_PTR(left) = PT_T_IMP(right);
+  */
+  t = PT_T_IMP(left);
+  t->nxt = PT_T_IMP(right);
   return( left );
 }
 
@@ -749,7 +753,7 @@ bool PT_df_getIT(PT_Itr iter)
    in depth first, prae/post order ;
    returns False on end-of-term
 */
-{ StdCPtr t;
+{ StdCPtr t = NULL;
   BUG_NULL(iter);
   switch( PT_I_CST(iter) )
   {
@@ -810,7 +814,7 @@ bool PT_bf_getIT(PT_Itr iter)
    in breast first, prae/post order; 
    returns False on end-of-term
 */
-{ StdCPtr t;
+{ StdCPtr t = NULL;
   BUG_NULL(iter);
   switch( PT_I_CST(iter) )
   {
@@ -1130,7 +1134,14 @@ static void PT_fgetNode(BinImg_T img, PT_Term* PTree)
     PT_P_FIL(*PTree) = (symbol)NULL;
   }
   if( CFG_CFG(PT_M_STP(PTree)) ) 
+  {
+    /* breaks strict-aliasing rules
     PT_fgetT(img,(PT_Term*)PT_T_SUB_PTR(*PTree));
+    */
+    PT_Term t = NULL;
+    PT_fgetT(img,&t);
+    PT_T_IMP(*PTree)->val = t;
+  }
   else
   if( ! CFG_NTM(PT_M_STP(*PTree)) ) 
     fgetReference(img,PT_T_VAL_PTR(*PTree),fgetSymbol);
@@ -1182,13 +1193,22 @@ void PT_fgetT(BinImg_T img, PT_Term* PTree)
   { PTERM* ts;
     fgetWord(img,&cnt);
     if( PT_T_TYP(*PTree) >= 0 )
-    { PTERM** t;
+    { 
+      /* break strict-aliasing rules
+      PTERM** t;
       t = PT_T_SUB_PTR(*PTree);
       for( i=0; i < cnt; ++i )
       { 
         fgetReference(img,(PT_Term*)((StdCPtr)&ts),PT_fgetT);
         *t = ts; t = PT_T_NXT_PTR(ts);
       }
+      */
+      PTERM* t = PT_T_IMP(*PTree);
+      for( i=0; i < cnt; ++i )
+      { 
+        fgetReference(img,(PT_Term*)((StdCPtr)&ts),PT_fgetT);
+        t->val = ts; t = PT_T_NXT(ts);
+      }
     }
     else
     { List(PT_Term)* t;
@@ -1726,8 +1746,9 @@ long PT_putSymbol(symbol s)
   PT_PUT_BUG; BUG_NULL(s);
   if( ! MAP_defined(Abs_SymbolRef,s) )
   { long len = OT_GET(long,AbsSymbol,0);
+    long dmy = 0;
     len += strlen(symbolToString(s))+1;
-    OT_UPD(long,AbsSymbol,0,len);
+    dmy = OT_UPD(long,AbsSymbol,0,len);
     idx = OT_T_INS(AbsSymbol,s);
     MAP_dfndom(Abs_SymbolRef,s,idx);
   }
@@ -1849,9 +1870,9 @@ void PT_putAbsT(void)
 /* puts all abstract term references
    to the current ( previously opened ) binary image
 */
-{
+{ long dmy = 0;
   PT_PUT_BUG;
-  OT_UPD(long,AbsTerm,0,OT_CNT(AbsTerm)-1);
+  dmy = OT_UPD(long,AbsTerm,0,OT_CNT(AbsTerm)-1);
   putHuge((HugeCPtr)OT_TRICKY_objects(AbsTerm),OT_CNT(AbsTerm)*sizeof(long)); 
 }
 
