@@ -180,8 +180,8 @@ namespace styx
       { T_Node& n = t.getNode();
         if( o == TI_STATE_PRAE )
         {
-          //fprintf(stdout,"\n%*s",2*l,"");
-          fprintf(stdout,"\n%*s",l,"");
+          //fprintf(stdout,"\n%*s",(int)(2*l),"");
+          fprintf(stdout,"\n%*s",(int)l,"");
           cout << "[";
           if( n.isComment() ) cout << "Comment";
           else
