@@ -31,6 +31,13 @@
   3. let X :ign#*: Y          <1 nonterminal>
   4. let X :name : X1 .. Xn   <n >= 0 && name =/= { ign#, nil, cons }>
 
+  Extension for options (styx version >= 1):
+
+  5. let X :none :            <0 members>
+  6. let X :some : Y          <1 member>
+  7. let X :name : X1 .. Xn   <n >= 0 && name =/= { ign#, nil, cons, none, some }>
+  
+
   B) construction of the token/nonterminal classes:
   1. X <=> X                          reflexiv 
   2. X <=> Y --> Y <=> X              symmetric
@@ -53,9 +60,18 @@
   1. X <=> Y --> Type(X) = Type(Y), where Type(Z) = { token, nonterminal }
   2. let X^ :id: a && let X^ :id: b --> a <=> b
   3. let X^ :nil: a || let X^ :cons: b
-     --> not exists P: P = let X^ :id: c && id =/= { ign1, nil, cons }
+     --> not exists P: P = let X^ :id: c && id =/= { ign#, nil, cons }
   [ 1,2: checked during construction ]
 
+  Extension for options (styx version >= 1):
+
+  4. let X^ :none: a || let X^ :some: b
+     --> not exists P: P = let X^ :id: c && id =/= { ign#, none, some }
+  5. let X^ :none: a 
+     --> exists P: P = let X^ :some: b
+  6. let X^ :some: a 
+     --> exists P: P = let X^ :none: b
+
   E) abstract context free grammar:
      NT |--> NT^
      T  |--> T^ ( NT^ T^ are the class representants )
@@ -107,6 +123,7 @@ typedef struct _PRDFN {
 typedef struct _KFGDFN {
 /* context free grammar ( definition interface ) */
   string language; /* language            */
+  int    version;  /* styx version        */
   OT_Tab Token;    /* token               */
   OT_Tab TkIdx;    /* token indexes       */
   OT_Tab NtIdx;    /* nonterminal indexes */
@@ -151,6 +168,7 @@ typedef struct _PrsGen_T {
   int      MaxSymCnt;    /* max. Anzahl Produktionssymbole      */
   int      MaxSymNamLen; /* max. Laenge der Symbol Namen        */
   int      conflictCnt;  /* Anzahl Konflikte                    */
+  int      version;      /* styx version                        */
   
   OT_Tab*  NtEquiv;      /* Equivalence Tables of Nonterminals  */
       
@@ -423,39 +441,52 @@ static int wellProd(PrsGen_T* PrsGen, KFGPROD* prod)
     else                              return( PROD_NIL );
   }
   else
+  if( consProd(prod->pname) )
   {
-    if( consProd(prod->pname) )
+    for( cnt=0, i=0; i < prod->symcnt; ++i )
     {
-      for( cnt=0, i=0; i < prod->symcnt; ++i )
-      {
-        typ  = symType(PrsGen,prod->symbols[i]);
-        cnt += CFG_TOK_NTM(typ);
-        if( cnt == 2 && CFG_NTM(typ) ) res = prod->symbols[i];
-      }
-      if( cnt != 2 ) return( PROD_FALSE );
-      else           return( res );
-    }
-    else
-    {
-      if( ignProd(prod->pname) )
-      {
-        for( cnt=0, i=0; i < prod->symcnt; ++i )
-        {
-          typ  = symType(PrsGen,prod->symbols[i]);
-          cnt += CFG_TOK_NTM(typ);
-          if( cnt == 1 && CFG_NTM(typ) ) res = prod->symbols[i];
-        }
-        if( cnt != 1 ) return( PROD_FALSE );
-        else           return( res );
-      }
-      else return( PROD_NORMAL );
+      typ  = symType(PrsGen,prod->symbols[i]);
+      cnt += CFG_TOK_NTM(typ);
+      if( cnt == 2 && CFG_NTM(typ) ) res = prod->symbols[i];
     }
+    if( cnt != 2 ) return( PROD_FALSE );
+    else           return( res );
   }
+  else
+  if( ignProd(prod->pname) )
+  {
+    for( cnt=0, i=0; i < prod->symcnt; ++i )
+    {
+      typ  = symType(PrsGen,prod->symbols[i]);
+      cnt += CFG_TOK_NTM(typ);
+      if( cnt == 1 && CFG_NTM(typ) ) res = prod->symbols[i];
+    }
+    if( cnt != 1 ) return( PROD_FALSE );
+    else           return( res );
+  }
+  else
+  if( PrsGen->version >= 1 && noneProd(prod->pname) )
+  {
+    if( cntProdMembers(PrsGen,prod) ) return( PROD_FALSE );
+    else                              return( PROD_NORMAL );
+  }
+  else
+  if( PrsGen->version >= 1 && someProd(prod->pname) )
+  {
+    for( cnt=0, i=0; i < prod->symcnt; ++i )
+    {
+      typ  = symType(PrsGen,prod->symbols[i]);
+      cnt += CFG_TOK_NTM(typ);
+    }
+    if( cnt != 1 ) return( PROD_FALSE );
+    else           return( PROD_NORMAL );
+  }
+  else return( PROD_NORMAL );
 }
 
 static void checkListProds(PrsGen_T* PrsGen, int ntclass)
 /* checks condition 3 for 'ntclass' */
-{ bool isList = False; bool isOther = False;
+{ bool isList = C_False; bool isOther = C_False;
   int cnt = OT_CNT(NTEQUIV(ntclass)), i; 
   for( i=0; i < cnt; ++i )
   { int nti = OT_GET(int,NTEQUIV(ntclass),i), j;
@@ -464,9 +495,9 @@ static void checkListProds(PrsGen_T* PrsGen, int ntclass)
 /*
 printf("%s.%s.%s\n",PrsGen->Kfg->SNames[NTSYMBOL(ntclass)],PrsGen->Kfg->SNames[prod->id],prod->pname);
 */
-      if( nilProd(prod->pname) || consProd(prod->pname) ) isList = True;
+      if( nilProd(prod->pname) || consProd(prod->pname) ) isList = C_True;
       else
-        if( ! ignProd(prod->pname) ) isOther = True;
+        if( ! ignProd(prod->pname) ) isOther = C_True;
       bug1
       ( 
         ! ( isList && isOther ), 
@@ -477,6 +508,38 @@ printf("%s.%s.%s\n",PrsGen->Kfg->SNames[NTSYMBOL(ntclass)],PrsGen->Kfg->SNames[p
   }
 }
 
+static void checkOptProds(PrsGen_T* PrsGen, int ntclass)
+/* checks condition 4 for 'ntclass' */
+{ bool isNone = C_False; bool isOther = C_False; bool isSome = C_False;
+  int cnt = OT_CNT(NTEQUIV(ntclass)), i; 
+  for( i=0; i < cnt; ++i )
+  { int nti = OT_GET(int,NTEQUIV(ntclass),i), j;
+    for( j =  FIRSTNTPROD(NTSYMBOL(nti)); j <= LASTNTPROD(NTSYMBOL(nti)); ++j )
+    { KFGPROD* prod = &PrsGen->ProdTab[j];
+/*
+printf("%s.%s.%s\n",PrsGen->Kfg->SNames[NTSYMBOL(ntclass)],PrsGen->Kfg->SNames[prod->id],prod->pname);
+*/
+      if( noneProd(prod->pname) ) isNone = C_True;
+      else
+      if( someProd(prod->pname) ) isSome = C_True; 
+      else
+      if( ! ignProd(prod->pname) ) isOther = C_True;
+      bug1
+      ( 
+        ! ( (isNone || isSome) && isOther ), 
+        "[%s] consists of option/non option productions",
+        PrsGen->Kfg->SNames[prod->id]
+      );
+    }
+  }
+  bug1
+  ( 
+    ( (isNone && isSome) || (!isNone && !isSome) ), 
+    "[%s] incomplete option productions",
+    PrsGen->Kfg->SNames[NTSYMBOL(ntclass)]
+  );
+}
+
 static void changeNtClass(PrsGen_T* PrsGen, int ntidx, int newClass)
 /* Class(ntidx) = newClass */
 {
@@ -583,6 +646,10 @@ static void pass2NtPartition(PrsGen_T* PrsGen)
     }
   }
   forallNtClasses(PrsGen,checkListProds);
+  if( PrsGen->version >= 1 )
+  {
+    forallNtClasses(PrsGen,checkOptProds);
+  }
 }
 
 /* ------------------------ Release Globals --------------------------------- */
@@ -1842,13 +1909,14 @@ static void printNtClasses(PrsGen_T* PrsGen)
 
 /*I----------------------- Grammar definition ------------------------------- */
 
-PLR_Cfg PLR_createCfg(string Language)
+PLR_Cfg PLR_createCfg(string Language, int version)
 /* creates a context free grammar definition named 'Language' */
 { KFGDFN* cfg;
 
   BUG_NULL(Language);
   cfg           = (KFGDFN*)NewMem(sizeof(KFGDFN));
   cfg->language = StrCopy(Language);
+  cfg->version  = version;
   cfg->Token    = NEW_STRTAB;
   cfg->TkIdx    = (OT_Tab)NULL;
   cfg->NonTerm  = NEW_STRTAB;
@@ -2054,6 +2122,7 @@ static PLR_Tab PLR_createTab_aux
   PrsGen.prMsg       = prExtMsg;
   PrsGen.profile     = verbose;
   PrsGen.conflictCnt = 0;
+  PrsGen.version     = PLR_C_IMP(Cfg)->version;
   if( PrsGen.profile ) (*prMsg)("begin parse table creation ...\n");
   if( PrsGen.profile ) (*prMsg)("reading grammar information ...\n");
   setKfgGlobals(&PrsGen,Cfg);
