@@ -1781,7 +1781,7 @@ static c_bool SD_load(StyDoc_T* ppStyDoc)
     GLS_Tok             pIde;
     // fill documentation base
     styx_Start_Source(pStyDoc->pTree,&pSrc);
-    styxSource_root(pSrc,&pIde,&pQDfns,&pOptCfg);
+    styxSource_root(pSrc,_,&pIde,&pQDfns,&pOptCfg);
     SD_load_com(pStyDoc);
     SD_load_lex(pQDfns,pStyDoc);
     if( styxOptCfg_cfg(pOptCfg,&pDfns) && ! GLS_EMPTY(pDfns) )
